@@ -1,5 +1,4 @@
 # Python modules
-import sys
 import hashlib
 
 # 3rd party modules
@@ -8,7 +7,6 @@ import posix_ipc
 # Utils for this demo
 import utils
 
-PY_MAJOR_VERSION = sys.version_info[0]
 
 utils.say("Oooo 'ello, I'm Mrs. Conclusion!")
 
@@ -36,13 +34,11 @@ for i in range(0, params["ITERATIONS"]):
         utils.say("Received %s" % s)
 
     if what_i_sent:
-        if PY_MAJOR_VERSION > 2:
-            what_i_sent = what_i_sent.encode()
+        what_i_sent = what_i_sent.encode()
         try:
             assert(s == hashlib.md5(what_i_sent).hexdigest())
         except AssertionError:
-            utils.raise_error(AssertionError,
-                              "Message corruption after %d iterations." % i)
+            raise AssertionError("Message corruption after %d iterations." % i)
     # else:
         # When what_i_sent is blank, this is the first message which
         # I always accept without question.
